==> haskell-wl-pprint-terminfo-3.7.1.4-81-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-terminfo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-terminfo
version: 3.7.1.4
id: wl-pprint-terminfo-3.7.1.4-JporxWijfKnG31jJGHMaFO
key: wl-pprint-terminfo-3.7.1.4-JporxWijfKnG31jJGHMaFO
license: BSD-3-Clause
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-terminfo/
synopsis: A color pretty printer with terminfo support
description:
    A color pretty printer with terminfo support
category: Control, Monads, Text
abi: 44993d72ebea503e48c47ba4f032a039
exposed: True
exposed-modules:
    System.Console.Terminfo.PrettyPrint
hidden-modules: System.Console.Terminfo.PrettyPrint.Curses
import-dirs: /usr/lib/ghc-8.6.3/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs: /usr/lib/ghc-8.6.3/site-local/wl-pprint-terminfo-3.7.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-wl-pprint-terminfo
hs-libraries: HSwl-pprint-terminfo-3.7.1.4-JporxWijfKnG31jJGHMaFO
extra-libraries:
    ncursesw
includes:
    cursed.h
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    terminfo-0.4.1.2 text-1.2.3.1 transformers-0.5.5.0
    wl-pprint-extras-3.5.0.5-LH4BswsZMhsChKV6fGC237
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-terminfo/html/wl-pprint-terminfo.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-terminfo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-terminfo-3.7.1.4-82-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-terminfo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-terminfo
version: 3.7.1.4
id: wl-pprint-terminfo-3.7.1.4-GLhkiRDc8YSG2vvQExeWwZ
key: wl-pprint-terminfo-3.7.1.4-GLhkiRDc8YSG2vvQExeWwZ
license: BSD-3-Clause
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-terminfo/
synopsis: A color pretty printer with terminfo support
description:
    A color pretty printer with terminfo support
category: Control, Monads, Text
abi: d7432a94cba2879b45a18479785af878
exposed: True
exposed-modules:
    System.Console.Terminfo.PrettyPrint
hidden-modules: System.Console.Terminfo.PrettyPrint.Curses
import-dirs: /usr/lib/ghc-8.6.3/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs: /usr/lib/ghc-8.6.3/site-local/wl-pprint-terminfo-3.7.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-wl-pprint-terminfo
hs-libraries: HSwl-pprint-terminfo-3.7.1.4-GLhkiRDc8YSG2vvQExeWwZ
extra-libraries:
    ncursesw
includes:
    cursed.h
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    terminfo-0.4.1.2 text-1.2.3.1 transformers-0.5.5.0
    wl-pprint-extras-3.5.0.5-CV1NIPz6G3e7Ee20Nte5B2
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-terminfo/html/wl-pprint-terminfo.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-terminfo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
